@@ -1,13 +1,14 @@
 
+from contextlib import suppress
 import time
 
 
 class Notes:
     "Notes are stored in `LiveSlide` class for consistensy."
-    def __init__(self,_insatanceLiveSlides, _instanceWidgets):
+    def __init__(self,_insatanceSlides, _instanceWidgets):
         "Instance should be inside `LiveSlide` class."
         # print(f'Inside: {self.__class__.__name__}')
-        self.main = _insatanceLiveSlides
+        self.main = _insatanceSlides
         self.widgets = _instanceWidgets
         
         self.notes_check = self.widgets.checks.notes
@@ -19,8 +20,13 @@ class Notes:
         self.btn_timer.observe(self.__timeit,names=['value'])
         
     def insert(self, content):
-        "Add notes to current slide. Content could be any object except javascript and interactive widgets."
-        self.main._slides_notes[self.main._current_slide] = self.main.format_html(content)._repr_html_()
+        """Add notes to current slide. Content could be any object except javascript and interactive widgets.
+        Alternatively you can add using `%notes notes content` magic.
+        
+        **New in 1.7.2**      
+        In markdown, you can use alert`notes&#96;notes content&#96;`."""
+        with suppress(BaseException): # Would work on next run, may not first time
+            self.main._running_slide._notes = self.main.format_html(content)._repr_html_()
     
     def _display(self, html_str):
         self.widgets.htmls.notes.value = 'Notes Area: Time only updates while switching slides' # Must be, so when no notes, should not be there
