@@ -3,27 +3,30 @@ Author Notes: Classes in this module should only be instantiated in LiveSlide cl
 and then provided to other classes via composition, not inheritance.
 """
 
-import os 
+from contextlib import suppress
+import os, sys
 import datetime
 from IPython import get_ipython
 from IPython.display import display, Image, Javascript
 from IPython.utils.capture import capture_output
+from ipywidgets import Layout
+
 from ..formatter import fix_ipy_image, code_css
 from ..extended_md import parse_xmd
-from ..utils import set_dir, html, details
+from ..utils import set_dir, html, details, today
 from . import scripts, intro, styles
 
 class LayoutSettings:
     def __init__(self, _instanceWidgets):
         "Provide instance of LivSlides to work."
         self.widgets = _instanceWidgets
-        self.animation = styles.animations['slide']
         self.font_scale = 1
-        self._font_family = {'code':'var(--jp-code-font-family)','text':'STIXGeneral'}
+        self._font_family = {'code':'var(--jp-code-font-family)','text':'STIX Two Text'}
         self._footer_text = 'IPySlides | <a style="color:skyblue;" href="https://github.com/massgh/ipyslides">github-link</a>'
         self._content_width = '90%' #Better
         self._breakpoint_width = f'{int(100*650/self.widgets.sliders.width.value)}px' # Whatever was set initially
         self._code_lineno = True
+        self._slide_layout = Layout(height='auto',margin='auto',overflow='auto',padding='0.2em 2em')
         
         self.height_slider = self.widgets.sliders.height
         self.width_slider  = self.widgets.sliders.width
@@ -35,7 +38,7 @@ class LayoutSettings:
         self.btn_zoom  = self.widgets.toggles.zoom
         self.btn_timer = self.widgets.toggles.timer
         self.box = self.widgets.panelbox
-        self.box.on_displayed(self._on_displayed) # First attempt of Javascript to work
+        self._on_load_and_refresh() # First attempt of Javascript to work
         
         self.theme_dd.observe(self._update_theme,names=['value'])
         self.scale_slider.observe(self.__set_font_scale,names=['value'])
@@ -52,36 +55,29 @@ class LayoutSettings:
         self.set_code_style() #Trigger CSS in it, must
         self.set_layout(center = True) # Trigger this as well
         
-    def _on_displayed(self,change):
+    def _on_load_and_refresh(self): # on_displayed is not working in in 8.0.0+
         self.__add_js()
         
         with capture_output() as cap:
-            parse_xmd(intro.instructions,display_inline=True)
+            with suppress(BaseException): # When ipython is not running, avoid errors
+                parse_xmd(intro.instructions,display_inline=True)
         # Only do this if it's in Jupyter, otherwise throws errors
         self.widgets.htmls.intro.value = details('\n'.join(o.data['text/html'] for o in cap.outputs), summary="Instructions").value
         self.widgets.htmls.intro.add_class('Intro')
             
-    def set_animation(self,name):
-        "Set animation style or pass None to disable animation."
-        if name is None:
-            self.animation = '' #Disable animation
-        elif name in styles.animations:
-            self.animation = styles.animations[name]
-        else:
-            print(f'Animation {name!r} not found. Pass None or any of {list(styles.animations.keys())}.')
-    
-    def set_code_style(self,style='default',color = None,background = None, accent_color = 'var(--tr-hover-bg)',lineno = True):
+    def set_code_style(self,style='default',color = None,background = None, hover_color = 'var(--tr-hover-bg)',lineno = True):
         "Set code style CSS. Use background for better view of your choice. This is overwritten by theme change."
         self._code_lineno = lineno # Used in theme to keep track 
-        self.widgets.htmls.hilite.value = code_css(style,color = color,background = background, lineno = lineno, accent_color = accent_color)
+        self.widgets.htmls.hilite.value = code_css(style,color = color,background = background, lineno = lineno, hover_color = hover_color)
       
     def set_font_family(self,text_font=None,code_font=None):
         "Set main fonts for text and code."
         if text_font:
             self._font_family['text'] = text_font
         if code_font:
-            self._font_family['code'] = code_font  
-        self._update_theme() # Changes Finally 
+            self._font_family['code'] = code_font
+        
+        self._update_theme() # Changes Finally
     
     def set_font_scale(self,font_scale=1):
         "Set font scale to increase or decrease text size. 1 is default."
@@ -107,10 +103,10 @@ class LayoutSettings:
             _text = self._footer_text
             
         if show_date:
-            _text += f' | <text style="color:var(--secondary-fg);">' + datetime.datetime.now().strftime('%b-%d-%Y')+ '</text>'
+            _text += f' | {today(color = "var(--secondary-fg)")}'
         if show_slideno: #Slide number should be replaced from __number__ 
             _text += '<b style="color:var(--accent-color);white-space:pre;">  __number__<b>'
-        _text = f'<p style="white-space:nowrap;"> {_text} </p>'
+        _text = f'<p style="white-space:nowrap;display:inline;"> {_text} </p>' # To avoid line break in footer
         
         self.widgets.htmls.footer.value = _text.replace('__number__',_number_str)
         
@@ -124,9 +120,19 @@ class LayoutSettings:
             style_dict.update(dict(margin = '8px auto',align_items = 'baseline',justify_content = 'flex-start'))
         
         for k,v in style_dict.items():
-            setattr(self.widgets.outputs.slide.layout, k, v)
+            setattr(self._slide_layout,k,v)
         
         self._update_theme(change=None) # Trigger CSS in it to make width change
+        
+    def hide_navigation_gui(self):
+        "Hide all navigation elements, but keyboard or touch still work."
+        self.widgets.controls.layout.display = 'none'
+        self.widgets.footerbox.layout.display = 'none'
+    
+    def show_navigation_gui(self):
+        "Show all navigation elements."
+        self.widgets.controls.layout.display = ''
+        self.widgets.footerbox.layout.display = ''
             
     def __add_js(self):
         with self.widgets.outputs.fixed: 
@@ -154,12 +160,12 @@ class LayoutSettings:
         
         
     def _update_theme(self,change=None): 
-        text_size = '{}px'.format(int(self.font_scale*16))
+        text_size = '{}px'.format(int(self.font_scale*20))
         
         if self.theme_dd.value != 'Custom':
             theme_css =  styles.style_css(styles.theme_roots[self.theme_dd.value])
         else: # In case of Custom CSS
-            with set_dir(get_ipython().starting_dir):
+            with set_dir(self.widgets.assets_dir):
                 if not os.path.isfile('custom.css'):
                     with open('custom.css','w') as f:
                         f.write('/* Author: Abdul Saboor */\n' + styles.style_css( styles.theme_roots['Light']))
@@ -168,12 +174,18 @@ class LayoutSettings:
                 with open('custom.css','r') as f:
                     theme_css = ''.join(f.readlines())
         
-        if self.theme_dd.value == 'Dark':
+        if 'Dark' in self.theme_dd.value:
             self.set_code_style('monokai',color='#f8f8f2',lineno=self._code_lineno)
+            light = '120'
         elif self.theme_dd.value == 'Fancy':
             self.set_code_style('borland',lineno=self._code_lineno) 
+            light = '230'
         else:
             self.set_code_style('default',lineno=self._code_lineno)
+            light = '250'
+            
+        if self.theme_dd.value in ['Inherit', 'Custom']:
+            light = '-' # Use Fallback colors, can't have idea which themes colors would be there
                
         # Replace font-size and breakpoint size
         theme_css = theme_css.replace(
@@ -181,7 +193,8 @@ class LayoutSettings:
                         '__textfont__',self._font_family['text']).replace(
                         '__codefont__',self._font_family['code']).replace(
                         '__content_width__',self._content_width).replace(
-                        '__breakpoint_width__', self._breakpoint_width  
+                        '__breakpoint_width__', self._breakpoint_width).replace(
+                        '__light__',light
                         )
         
         # Update CSS
@@ -193,7 +206,7 @@ class LayoutSettings:
         self._emit_resize_event()
         
     def _toggle_sidebar(self,change): 
-        """Pushes this instance of LiveSlides to sidebar and back inline."""
+        """Pushes this instance of Slides to sidebar and back inline."""
         # Only push to sidebar if not in fullscreen
         if self.btn_fs.value or self.sidebar_switch.value == False:
             self.widgets.mainbox.remove_class('SideMode')
@@ -217,7 +230,9 @@ class LayoutSettings:
             self._breakpoint_width = f'{int(100*650/self.width_slider.value)}px'
             self.btn_fs.icon = 'expand'
             self.widgets.mainbox.remove_class('FullScreen') # back to inline
-            
+            if self.btn_zoom.value:
+                self.btn_zoom.value = False # Unzoom to avoid jerks in display
+                
         self.widgets.htmls.fscrn.value = html('style', styles.fullscreen_css if self.btn_fs.value else '').value
         self._emit_resize_event() # Resize before waiting fo update-theme
         self._update_theme(change=None) # For updating size and breakpoints
