@@ -2,6 +2,7 @@
 Author Notes: Classes in this module should only be instantiated in LiveSlide class or it's parent class
 and then provided to other classes via composition, not inheritance.
 """
+import os
 from dataclasses import dataclass
 import ipywidgets as ipw
 from IPython.display import display, Javascript
@@ -20,7 +21,7 @@ class _Buttons:
     """
     prev    =  Button(icon='chevron-left',layout= Layout(width='auto',height='auto')).add_class('arrows')
     next    =  Button(icon='chevron-right',layout= Layout(width='auto',height='auto')).add_class('arrows')
-    setting =  Button(description= '\u2630',layout= Layout(width='auto',height='auto')).add_class('menu').add_class('float-cross-btn')
+    setting =  Button(description= '\u2630',layout= Layout(width='auto',height='auto')).add_class('menu').add_class('SidePanel-Btn')
     capture =  Button(icon='camera',layout= Layout(width='auto',height='auto'),
                 tooltip='Take Screen short in full screen. Order of multiple shots in a slide is preserved!',
                 ).add_class('screenshot-btn') # .add_class('menu')
@@ -44,18 +45,18 @@ class _Htmls:
     """
     Instantiate under `Widgets` class only.
     """
-    footer  = HTML('<p>Put Your Info Here using `self.set_footer` function</p>').add_class('Footer')
+    footer  = HTML('<p>Put Your Info Here using `self.set_footer` function</p>',layout=Layout(margin='0')).add_class('Footer') # Zero margin is important
     theme   = HTML(html('style',styles.style_css(styles.theme_roots['Fancy'].replace(
-                '__text_size__','16px')).replace(
+                '__text_size__','20px')).replace(
                 '__breakpoint_width__','650px').replace(
-                '__textfont__','sans-serif').replace(
+                '__textfont__','STIX Two Text').replace(
                 '__codefont__','var(--jp-code-font-family)')
                 ).value)
     main    = HTML(html('style',styles.main_layout_css).value)
     sidebar = HTML(html('style',styles.sidebar_layout_css()).value) # Should be separate CSS
     loading = HTML() #SVG Animation in it
     logo    = HTML()
-    toast   = HTML() # For notifications
+    toast   = HTML().add_class('Toast') # For notifications
     cursor  = HTML().add_class('LaserPointer') # For beautiful cursor
     notes   = HTML('Notes Area').add_class('Inline-Notes') # For below slides area
     hilite  = HTML() # Updated in settings on creation. For code blocks.
@@ -64,6 +65,7 @@ class _Htmls:
     capture = HTML('<span class="Info">Edit above box and hit Enter to see screenshot here. ' 
                    'If nothing shown, your system does not support taking screenshots with PIL</span>').add_class('capture-html') # Screenshot image here
     intro   = HTML().add_class('panel-text') # Intro HTML
+    glass = HTML().add_class('BackLayer') # For glass effect
 
 @dataclass(frozen=True)
 class _Inputs:
@@ -107,7 +109,7 @@ class _Outputs:
     """
     Instantiate under `Widgets` class only.
     """
-    slide = ipw.Output(layout= Layout(height='auto',margin='auto',overflow='auto',padding='2px 36px') # do not set width here, in css
+    slide = ipw.Output(layout= Layout(height='0',width = '0',margin='0',opacity='0') # for hodling slide CSS
             ).add_class('SlideArea')
     fixed = ipw.Output(layout=Layout(width='auto',height='0px')) # For fixed javascript
     renew = ipw.Output(layout=Layout(width='auto',height='0px')) # Content can be added dynamically
@@ -200,12 +202,24 @@ class Widgets:
     """
     def __setattr__(self, name , value):
         if name in self.__dict__:
-            raise AttributeError(f'{name} is a read-only attribute')
+            if name == '_notebook_dir':
+                self.__dict__[name] = value
+            else:
+                raise AttributeError(f'{name} is a read-only attribute')
         
         self.__dict__[name] = value
         
+    @property
+    def assets_dir(self):
+        "Returns the assets directory, if not exist, create one"
+        _dir = os.path.join(self._notebook_dir,'ipyslides-assets')
+        if not os.path.isdir(_dir):
+            os.makedirs(_dir)
+        return _dir
+        
     def __init__(self):
         # print(f'Inside: {self.__class__.__name__}')
+        self._notebook_dir = '.' # This will be updated later
         self.buttons = _Buttons()
         self.toggles = _Toggles()
         self.sliders = _Sliders()
@@ -229,9 +243,9 @@ class Widgets:
         
         self.footerbox = HBox([
             self.buttons.setting,
-            HBox([self.htmls.footer],layout= Layout(overflow_x = 'auto',overflow_y='hidden')) ,
-            self.buttons.capture
-        ],layout=Layout(height='32px')).add_class('nav-box')
+            HBox([self.htmls.footer],layout= Layout(overflow_x = 'auto',overflow_y='hidden')),
+            self.buttons.capture,
+        ],layout=Layout(height='36px')).add_class('nav-box')
         
         self.navbox = VBox([
             self.footerbox,
@@ -267,21 +281,23 @@ class Widgets:
                 self.htmls.capture,
                 self.outputs.fixed, 
                 self.outputs.renew,
+                self.outputs.slide,
                 self.htmls.intro  
             ],layout=Layout(width='auto',height='auto',overflow_y='scroll',padding='8px',margin='0'))
         ],layout = Layout(width='70%',min_width='50%',height='100%',overflow='hidden',display='none')).add_class('panel') 
         
         self.slidebox = Box([
-            self.outputs.slide 
+            # Slides are added here dynamically
         ],layout= Layout(min_width='100%',overflow='auto')).add_class('SlideBox') 
         
         self.mainbox = VBox([
+            self.htmls.glass, # This is the glass pane, should be on top of everything
             self.htmls.loading, 
             self.htmls.toast,
             self.htmls.main,
             self.htmls.theme,
             self.htmls.logo,
-            self.toggles.display, 
+            self.toggles.display,
             self.htmls.sidebar,
             self.panelbox, 
             self.htmls.cursor,
