@@ -1,22 +1,21 @@
 # Author: Abdul Saboor
 # This demonstrates that you can generate slides from a .py file too, which you can import in notebook.
-import textwrap, time
-from io import StringIO
-from IPython import get_ipython
-from .utils import textbox
-from .writers import write, iwrite
-from .formatter import libraries, __reprs__
-from ._base.intro import how_to_slide
+from contextlib import suppress
+import time
+from ipyslides.utils import textbox
 
-slides = get_ipython().user_ns['_s_l_i_d_e_s_'] # get slides from notebook instead of creating new one
+from ipyslides.writers import write, iwrite
+from ipyslides.formatter import libraries, __reprs__
+from ipyslides._base.intro import how_to_slide, logo_svg
+
+slides = globals()['slides'] # gloabals are update from calling function demo()
 slides.settings.set_footer('Author: Abdul Saboor عبدالصبور')
-slides.settings.set_logo('''<svg viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
-        <circle cx="50" cy="50" r="50" fill="blue"/>
-        <text x="45%" y="45%" fill="white" font-size="4em" dominant-baseline="central" text-anchor="middle">↑</text>
-        <text x="55%" y="60%" fill="white" font-size="4em" dominant-baseline="central" text-anchor="middle">↓</text></svg>''',width=50)
+slides.settings.set_logo(logo_svg,width=60) # This is by defualt a logo of ipyslides
+slides._citation_mode = 'global' # This could be changed by other functions
+slides.set_citations({'pf': 'This is refernce to FigureWidget using `slides.cite` command'})
 
-#Demo for loading slides from a file or file-like object 
-fp = StringIO('\n'.join(how_to_slide) + '''\n---
+#Demo for loading slides from a file or text block 
+s0, s1, s2 = slides.from_markdown(0,'\n'.join(how_to_slide) + '''\n---
 # Slide 1 {.Success}
 ```python run source
 import ipyslides as isd
@@ -28,29 +27,39 @@ Version: {{version}} as executed from below code in markdown.
 ---
 # Slide 2 {.Success}
 Created using `%%slide 2 -m` with markdown only
+[slide2]:`This is reference created using markdown`
+cite`slide2` Reference to this will show at end
 ```multicol
 # Column A
 ||### Sub column A {.Success}||### Sub column B ||
 +++
 # Column B
 ```
+notes`This is note created using markdown`
 That version from last slide is still in memory. See it is there {{version}}
-''')
-slides.from_markdown(fp, trusted=True) # This will create first slide along with title page.
+''',trusted=True)
+
+with s0.insert(0):
+    s0.source.display(collapsed = True)
 
 with slides.slide(1): #slide 1 will be modified with old and new content
     with slides.source.context(style='monokai', color='white', className='Mono') as s:
-        slides.parse_xmd(slides.md_content[1])
-        #display(*get_ipython().user_ns['outputs'])
-        write('## I am created using `with slides.slide(1)` context( manager!')
+        slides.parse_xmd(s1.markdown) #s1 was assigned as `s0, s1, s2 = slides.from_markdown...` in start.
+        write('#### I am created using `with slides.slide(1)` context manager, '
+            'so I overwrite the previous slide, and you can not see my full code, '
+            'but part of it using `Slides.source.context` context manager.')
         write(f'I am {slides.alert("Alerted")} and I am *{slides.colored("colored and italic text","magenta","whitesmoke")}*')
     s.focus_lines([0]).display()  #focus on line 0 
     slides.notes.insert('### Note for slide 1')
     
 slides.shell.user_ns['write'] = write #Inject variable in IPython shell
 
-#slide 2    
-slides.shell.run_cell_magic('slide','2 -m',slides.md_content[2])
+# Insert source of slide 2    
+with s2.insert(0):
+    s2.source.display(collapsed = True)
+
+s2.insert_markdown({-1: f'alert`I was added at end using {slides.backtick}s2.insert_markdown{slides.backtick}`'})
+    
 #slide 3
 online_sources = '''# IPySlides Online Running Sources 
 Launch as voila slides (may not work as expected [^1])[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/massgh/ipyslides-voila/HEAD?urlpath=voila%2Frender%2Fnotebooks%2Fipyslides.ipynb)
@@ -61,7 +70,7 @@ Launch as voila slides (may not work as expected [^1])[![Binder](https://mybinde
 Launch example Notebook [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/massgh/ipyslides-voila/HEAD?urlpath=lab%2Ftree%2Fnotebooks%2Fipyslides.ipynb)
 {.Note .Success}
 
-[^1]: Add references like this per slide. Use slides.cite() to add citations generally.
+[^1]: Add references like this per slide. Use slides.cite() or in markdown cite\`key\` to add citations generally.
 '''
 @slides.frames(3,'## I am created using `@slides.frames`',online_sources)
 def func(obj):
@@ -74,35 +83,37 @@ def func(obj):
 __contents = [f"""## IPython Display Objects
 #### Any object with following methods could be in`write` command:
 {', '.join([f'`_repr_{rep}_`' for rep in __reprs__])}
-Such as `IPython.display.<HTML,SVG,Markdown,Code>` etc. or third party such as `plotly.graph_objects.Figure`{{.Warning}}.            
+Such as color[navy_skyblue]`IPython.display.[HTML,SVG,Markdown,Code]` etc. or third party such as `plotly.graph_objects.Figure`{{.Warning}}.            
 """,
 f"""## Plots and Other **Data**{{style='color:var(--accent-color);'}} Types
 #### These objects are implemented to be writable in `write` command:
 {', '.join([f"`{lib['name']}.{lib['obj']}`" for lib in libraries])}
 Many will be extentended in future. If an object is not implemented, use `display(obj)` to show inline or use library's specific
-command to show in Notebook outside `write`.
+command to show in Notebook outside color[teal_whitesmoke]`write`.
 """,
 f"""## Interactive Widgets
-### Any object in `ipywidgets`{textbox('<a href="https://ipywidgets.readthedocs.io/en/latest/">Link to ipywidgtes right here using `textbox` command</a>')} 
-or libraries based on ipywidgtes such as `bqplot`,`ipyvolume`,plotly's `FigureWidget`{slides.cite('pf','This is refernce to FigureWidget using `slides.cite` command')}(reference at end)
+### Any object in `ipywidgets`{textbox('<a href="https://ipywidgets.readthedocs.io/en/latest/">Link to ipywidgtes right here using textbox command</a>')} 
+or libraries based on ipywidgtes such as color[red]`bqplot`,color[green]`ipyvolume`,plotly's `FigureWidget` cite`pf`(reference at end)
 can be included in `iwrite` command as well as other objects that can be passed to `write` with caveat of Javascript.
 {{.Warning}}
 """,
 '## Commands which do all Magic!']
 for i in range(4,8):
-    with slides.slide(i, background='skyblue'):
+    with slides.slide(i, props_dict = {'':dict(background = 'skyblue')}):
         write(__contents[i-4])
         if i == 7:
             with slides.source.context() as s:
-                write([slides.doc(write,'LiveSlides'), slides.doc(iwrite,'LiveSlides'), slides.doc(slides.parse_xmd,'LiveSlides')])
-                write("#### If an object does not render as you want, use `display(object)` or register it as you want using `@LiveSlides.serializer.register` decorator")
+                write([slides.doc(write,'Slides'), slides.doc(iwrite,'Slides'), slides.doc(slides.parse_xmd,'Slides')])
+                write("#### If an object does not render as you want, use `display(object)` or register it as you want using `@Slides.serializer.register` decorator")
             
             s.show_lines([0,1]).display()
+            
 # Matplotlib
-with slides.slide(8,background='linear-gradient(to right, #FFDAB9 0%, #F0E68C 100%)'):
+with slides.slide(8,props_dict = {'': dict(background='linear-gradient(to right, #FFDAB9 0%, #F0E68C 100%)')}):
     write('## Plotting with Matplotlib')
     with slides.source.context() as s:
         import numpy as np, matplotlib.pyplot as plt
+        plt.rcParams['svg.fonttype'] = 'none' # Global setting, enforce same fonts as presentation
         x = np.linspace(0,2*np.pi)
         with plt.style.context('ggplot'):
             fig, ax = plt.subplots(figsize=(3.4,2.6))
@@ -124,20 +135,21 @@ with slides.slide(9):
         s.display() # s = source.context(style='vs', className="Youtube")
     
 # Data Table
-with slides.slide(10):
-    with slides.source.context() as s:
-        write('## Data Tables')
-        write(slides.block_r('Here is Table',
-            textwrap.dedent('''
-            |h1|h2|h3|
-            |---|---|---|
-            |d1|d2|d3|
-            |r1|r2|r3|
-            ''')))
-        s.focus_lines([3,4,5,6]).display()
+slides.shell.user_ns['slides'] = slides #Inject variable in IPython shell to use in below cell magic
+slides.shell.run_cell_magic('slide','10',"""
+with slides.source.context() as s:
+    write('## Data Tables')
+    write(slides.block_r('Here is Table','<hr/>','''
+        |h1|h2|h3|
+        |---|---|---|
+        |d1|d2|d3|
+        |r1|r2|r3|
+        '''))
+    s.focus_lines([3,4,5,6]).display()
+""")
 
 # Plotly and Pandas DataFrame only show if you have installed
-with slides.slide(11,background='#800000'):
+with slides.slide(11,props_dict = {'':dict(background='#800000')}):
     with slides.source.context():
         try:
             import pandas as pd 
@@ -176,8 +188,8 @@ with slides.slide(13):
         import ipywidgets as ipw
         import numpy as np, matplotlib.pyplot as plt
         
-        write('## Interactive Apps on Slide\n Use `ipywidgets`, `bqplot`,`ipyvolume` , `plotly Figurewidget` etc. to show live apps like this!')
-        grid, [(plot,button, _), code] = slides.iwrite([
+        write('## Interactive Apps on color[var(--accent-color)]`Slide`\n Use `ipywidgets`, `bqplot`,`ipyvolume` , `plotly Figurewidget` etc. to show live apps like this!')
+        writer, (plot,button, _), code = slides.iwrite([
             '## Plot will be here! Click button below to activate it!',
             ipw.Button(description='Click me to update race plot',layout=ipw.Layout(width='max-content')),
             "[Check out this app](https://massgh.github.io/pivotpy/Widgets.html#VasprunApp)"],src.focus_lines([4,5,6,7,*range(24,30)]))
@@ -195,7 +207,7 @@ with slides.slide(13):
             
             ax.set(title='Race Plot', ylim = [-0.05,0.95], xticks=[],yticks=[c for c in x],yticklabels=[rf'$X_{int(c*10)}$' for c in x[_sort]])
             global plot # only need if you want to change something on it inside function
-            plot = grid.update(plot, fig) #Update plot each time
+            plot = writer.update(plot, fig) #Update plot each time
             
         def onclick(btn):
             plot_theme = 'dark_background' if 'Dark' in slides.settings.theme_dd.value else 'default'
@@ -220,14 +232,16 @@ def func(obj):
         slides.notes.insert(f'## This is under @frames decorator, so it will be shown only in first frame')
         slides.notify_later()(lambda: f'This is under @frames decorator, so it will be shown only in first frame')
         
-    slides.write([f'### This is Slide {14}.{obj-13}\n and we are animating matplotlib',
+    slides.write([f'### This is Slide {14}.{obj-14}\n and we are animating matplotlib',
                   s.show_lines([obj-14])
                   ],ax,width_percents=[40,60])
     if obj == 14:
         s.show_lines([5,6]).display()
+    
+    slides.write(slides.cite('This'))
         
 # Frames structure
-boxes = [f'<div style="background:var(--tr-hover-bg);width:auto;height:auto;padding:8px;margin:8px;border-radius:4px;"><h1>{i}</h1></div>' for i in range(1,10)]
+boxes = [f'<div style="background:var(--tr-hover-bg);width:auto;height:auto;padding:8px;margin:8px;border-radius:4px;"><h1>{i}</h1></div>' for i in range(1,5)]
 @slides.frames(15,*boxes, repeat=False)
 def f(obj):
     slides.write('# Frames with \n#### `repeat = False`')
@@ -238,26 +252,30 @@ def f(obj):
     slides.write('# Frames with \n#### `repeat = True`')
     slides.write(*obj,className='Warning')
     
-@slides.frames(17,*boxes, repeat=[(0,1,2),(3,4,5),(6,7,8)])
+@slides.frames(17,*boxes, repeat=[(0,1),(2,3)])
 def f(obj):
     with slides.source.context() as s:
-        slides.write('# Frames with \n#### `repeat = [(0,1,2),(3,4,5),(6,7,8)]`')
+        slides.write('# Frames with \n#### `repeat = [(0,1),(2,3)]`')
         slides.write(*obj)
     s.display()
 
 with slides.slide(18):
     with slides.source.context() as s:
-        slides.write(['## Displaying image from url from somewhere in Kashmir (کشمیر)',
-                      slides.image(r'https://assets.gqindia.com/photos/616d2712c93aeaf2a32d61fe/master/pass/top-image%20(1).jpg')],
-                     className='Success')
+        slides.write('## Displaying image from url from somewhere in Kashmir color[crimson]`(کشمیر)`')
+        try:
+            slides.image(r'https://assets.gqindia.com/photos/616d2712c93aeaf2a32d61fe/master/pass/top-image%20(1).jpg').display()
+        except:
+            slides.write('Could not retrieve image from url. Check internt connection!',className='Error')
     s.display()
 
-with slides.slide(19):
-    slides.write('## $\LaTeX$ in Slides\nUse `$ $` or `$$ $$` to display latex in Markdown, or embed images of equations')
-    slides.write('$\LaTeX$ needs time to load, so `slides.pre_compute_display()` will help\n{.Note .Warning}')
-    slides.write([r'\$\$\int_0^1\frac{1}{1-x^2}dx\$\$',
-                r'$$\int_0^1\frac{1}{1-x^2}dx$$'
-                ])  
+slides.from_markdown(19, '''## $\LaTeX$ in Slides
+Use `$ $` or `$$ $$` to display latex in Markdown, or embed images of equations
+$\LaTeX$ needs time to load, so keeping it in view until it loads would help.
+{.Note .Warning}
+
+\$\$\int_0^1\\frac{1}{1-x^2}dx\$\$
+$$\int_0^1\\frac{1}{1-x^2}dx$$
+''', trusted=True)
 
 with slides.slide(20):
     slides.write('## Built-in CSS styles')
@@ -275,7 +293,8 @@ with slides.slide(21):
             slides.cols('### Column A','### Column B',className='Info'),
             '||### Column C {.Warning}||### Column D {.Success}||',
         ).display()
-        slides.image(r'https://assets.gqindia.com/photos/616d2712c93aeaf2a32d61fe/master/pass/top-image%20(1).jpg').display()
+        slides.write('---')
+
     s.display()
     
 with slides.slide(22):
