@@ -12,13 +12,17 @@ A
 +++
 This {{var_name}} is a code from above and will be substituted with the value of var_name
 ```
-{{selective expression}} is allowed in 1.5.8+ only for a subset of functions in `LiveSlides` to include content dynamically.
-Get a list of all available functions by  `LiveSlides.markdown_callables`.
+
 Note: Nested blocks are not supported.
+
+**New in 1.7.2**    
+Find special syntax to be used in markdown by `Slides.xmd_syntax`.
+
+**New in 1.7.5**
+Use `Slides.extender` or `ipyslides.extended_md.extender` to add [markdown extensions](https://python-markdown.github.io/extensions/).
 """
 
-
-import textwrap, re, ast
+import textwrap, re
 from markdown import Markdown
 from IPython.core.display import display
 from IPython import get_ipython
@@ -27,17 +31,94 @@ from IPython.utils.capture import capture_output
 from .formatter import _HTML, highlight, stringify
 from .source import _str2code
 
+_md_extensions = ['tables','footnotes','attr_list','md_in_html', 'customblocks'] # For Markdown Parser
+_md_extension_configs = {}
 
-_md_extensions = ['tables','footnotes','attr_list'] # For MArkdown Parser
+class PyMarkdown_Extender:
+    def __init__(self):
+        "Adds extensions to the Markdown parser. See [Website of Python-Markdown](https://python-markdown.github.io/extensions/)"
+        self._exts = []
+        self._configs = {}
+    
+    def __repr__(self) -> str:
+        return "Extensions:\n" + repr(self._all) + "\nConfigs:\n" + repr(self._all_configs)
+        
+    @property
+    def _all(self):
+        return list(set([*self._exts, *_md_extensions]))
+    
+    @property
+    def _all_configs(self):
+        return {**self._configs, **_md_extension_configs}
+    
+    def extend(self,extensions_list):
+        "Add list of extensions to the Markdown parser."
+        self._exts = list(set([*self._exts, *extensions_list]))
+    
+    def config(self,configs_dict):
+        "Add configurations to the Markdown extensions. configs_dict is a dictionary like {'extension_name': config_dict}"
+        self._configs = {**self._configs, **configs_dict}
+    
+    def clear(self):
+        "Clear all extensions and their configurations added by user."
+        self._exts = []
+        self._configs = {}
+    
+    @property
+    def active(self):
+        "List of active extensions."
+        return {'extensions': self._all, 'configs': self._all_configs}
+  
+extender = PyMarkdown_Extender()
+del PyMarkdown_Extender
 
-_allowed_funcs = 'cite|citations_html|insert_notes|notes.insert|source.from_callable|source.from_file'
-_allowed_funcs += '|'.join(['|details','textbox','vspace','image','svg','format_css','alert','colored','raw','plt2html','bokeh2html','doc','sig'])
+_special_funcs = {
+    'alert':'text',
+    'image':'path/src',
+    'raw':'text',
+    'svg':'path/src', 
+    'iframe':'src',
+    'sub': 'text',
+    'sup': 'text',
+    'today': 'fmt like %b-%d-%Y',
+    'textbox':'text', # Anything above this can be enclosed in a textbox
+    'center':'text or \{\{variable\}\}',} # Center should be at end of all
+
+
+def resolve_objs_on_slide(slide_instance,text_chunk):
+    "Resolve objects in text_chunk corrsponding to slide such as cite, notes, etc."
+    # cite`key`
+    all_matches = re.findall(r'cite\`(.*?)\`', text_chunk, flags = re.DOTALL)
+    for match in all_matches:
+        key = match.strip()
+        text_chunk = text_chunk.replace(f'cite`{match}`', slide_instance.cite(key), 1)
+    
+    # notes`This is a note for current slide`
+    all_matches = re.findall(r'notes\`(.*?)\`', text_chunk, flags = re.DOTALL)
+    for match in all_matches:
+        slide_instance.notes.insert(match)
+        text_chunk = text_chunk.replace(f'notes`{match}`', '', 1)
+    
+    # citations`This is citations title`
+    all_matches = re.findall(r'citations\`(.*?)\`', text_chunk, flags = re.DOTALL)
+    for match in all_matches:
+        citations = slide_instance.citations_html(title = match).value
+        text_chunk = text_chunk.replace(f'citations`{match}`', citations, 1)
+    
+    # [key]:`citation content`
+    all_matches = re.findall(r'\[(.*?)\]\:\`(.*?)\`', text_chunk, flags = re.DOTALL)
+    citations = {}
+    for match in all_matches:
+        citations[match[0].strip()] = match[1]
+        slide_instance.set_citations(citations) # Only update under all_matches loop, otherwise it will be a mess of notifications
+        text_chunk = text_chunk.replace(f'[{match[0]}]:`{match[1]}`', '', 1)
+    
+    return text_chunk
 
 class _ExtendedMarkdown(Markdown):
     "New in 1.4.5"
     def __init__(self):
-        self.extensions = _md_extensions
-        super().__init__(extensions = self.extensions)
+        super().__init__(extensions = extender._all, extension_configs=extender._all_configs)
         self._display_inline = False
     
     def _extract_class(self, header):
@@ -55,9 +136,15 @@ class _ExtendedMarkdown(Markdown):
         New in 1.4.5
         """
         self._display_inline = display_inline # Must change here
+        xmd = textwrap.dedent(xmd) # Remove leading spaces from each line, better for writing under indented blocks
+        
+        slides_instance = get_ipython().user_ns.get('__Slides_Instance__',None)
+        if slides_instance and slides_instance._running_slide: # getattr(slides_instance,'_under_with_or_frame',False):
+            xmd = resolve_objs_on_slide(slides_instance,xmd) # Resolve objects in xmd related to current slide
+        
         if xmd[:3] == '```': # Could be a block just in start of file or string
             xmd = '\n' + xmd
-            
+        
         new_strs = xmd.split('\n```') # This avoids nested blocks and it should be
         outputs =[]
         for i, section in enumerate(new_strs):
@@ -137,54 +224,63 @@ class _ExtendedMarkdown(Markdown):
             # Run Code now
             with capture_output() as captured:
                 shell.run_cell(dedent_data) # Run after assigning it to variable, so can be accessed inside code too
-            return captured.outputs
-        
-    def _safe_eval(self, expression):
-        "Evaluate on allowed expressions in {{expression}}"
-        if ';' in expression: # This remove biggest security risk
-                raise ValueError(f'Multiple statements not allowed in expr -> {expression!r}')
-        
-        node = ast.parse(expression)
-        for n in ast.walk(node):
-            if isinstance(n, (ast.Import, ast.ImportFrom)):
-                raise ValueError(f'import commands are not allowed in expr -> {expression!r}')
-            if isinstance(n, ast.Call):
-                if not re.search(_allowed_funcs, expression):
-                    raise ValueError(f'''Arbitrary function calls not allowed in expr -> {expression!r}, use only following methods:\n{_allowed_funcs.replace("|",", ")}''')
-                elif re.search(_allowed_funcs, expression):
-                    _prefix, _main = expression.split('.',1), 'Forbidden'
-                    if len(_prefix) > 1:
-                        _main = get_ipython().user_ns[_prefix[0]] # Check if really inside the scope of slides
-                    if _main == 'Forbidden' or not _main.__name__.startswith('ipyslides'): # Can cover LiveSlides, parsers, utils etc'
-                        raise ValueError(f'Function {expression!r} not allowed in main scope in expr -> {expression!r}')
             
-        # Finally eval it
-        return eval(expression, {'__import__':None, **get_ipython().user_ns})
-    
+            outputs = captured.outputs
+            from ._base.slide import append_print_warning # Avoid circular import
+            append_print_warning(captured=captured, append_to=outputs)
+            return outputs
+        
     def _sub_vars(self, html_output):
-        "Substitute variables in html_output given as {{var}}, {{expression}}, and two inline columns as ||C1||C2||"
+        "Substitute variables in html_output given as {{var}} and two inline columns as ||C1||C2||"
             
         # Replace variables first 
-        all_matches = re.findall(r'\{\{(.*?)\}\}', html_output, flags = re.DOTALL)
         user_ns = get_ipython().user_ns
+        all_matches = re.findall(r'\{\{(.*?)\}\}', html_output, flags = re.DOTALL)
         for match in all_matches:
             output = match # If below fails, it will be the same as input line
             _match = match.strip()
             if _match in user_ns:
                 output = user_ns[_match]
             else:
-                output = self._safe_eval(_match) # eval allowed expressions
-            
+                raise ValueError(('{!r} is not executable. ' 
+                'Only variables are allowed in double curly braces or see Slides.xmd_syntax as well'))
+                
             _out = (stringify(output) if output is not None else '') if not isinstance(output, str) else output # Avoid None
             html_output = html_output.replace('{{' + match + '}}', _out, 1)
         
+        # Replace inline one argumnet functions
+        from . import utils # Inside function to avoid circular import
+        for func in _special_funcs.keys():
+            all_matches = re.findall(fr'{func}\`(.*?)\`', html_output, flags = re.DOTALL)
+            for match in all_matches:
+                _func = getattr(utils,func)
+                _out = _func(match).value if match else _func().value # If no argument, use default
+                html_output = html_output.replace(f'{func}`{match}`', _out, 1)
+        
         # Replace columns after vars, so not to format their brackets
         all_cols = re.findall(r'\|\|(.*?)\|\|(.*?)\|\|', html_output, flags = re.DOTALL) # Matches new line as well, useful for inline plots and big objects
         for cols in all_cols:
             _cols = ''.join(f'<div style="width:50%;">{self.convert(c)}</div>' for c in cols)
             _out = f'<div class="columns">{_cols}</div>'
             html_output = html_output.replace(f'||{cols[0]}||{cols[1]}||', _out, 1)
+              
+        # Replace Block classes
+        all_matches = re.findall(r'class\`(.*?)\`', html_output, flags = re.DOTALL)
+        for match in all_matches:
+            html_output = html_output.replace(f'class`{match}`', f'<div class="{match}" markdown="1">', 1)
         
+        
+        # Replace colored text
+        all_matches = re.findall(r'color\[(.*?)\]\`(.*?)\`', html_output, flags = re.DOTALL)
+        for match in all_matches:
+            kws = {'fg':None,'bg':None}
+            if '_' in match[0]:
+                kws['fg'], kws['bg'] = [c.strip() for c in match[0].split('_',1)]
+            else:
+                kws['fg'] = match[0].strip()
+            html_output = html_output.replace(f'color[{match[0]}]`{match[1]}`', utils.colored(match[1],**kws).value, 1)
+        
+        html_output = re.sub(r'^\^\^\^$', '</div>', html_output,flags=re.MULTILINE) # Close last block
         return html_output # return in main scope
             
 
@@ -217,15 +313,18 @@ def parse_xmd(extended_markdown, display_inline = True, rich_outputs = False):
 
     Each block can have class names (speparated with space or .) (in 1.4.7+) after all other options such as `python .friendly` or `multicol .Sucess.Info`.
     For example, `python .friendly` will be highlighted with friendly theme from pygments.
-    Pygments themes, however, are not supported with `multicol`. You need to write CSS for a custom class in <style> tag.
-    Aynthing with class name 'report-only' will not be displayed on slides, but appears in document when `LiveSlides.export.<export_function>` is called.
+    Pygments themes, however, are not supported with `multicol`. You need to write and display CSS for a custom class.
+    Aynthing with class name 'report-only' will not be displayed on slides, but appears in document when `Slides.export.<export_function>` is called.
 
     Note: Nested blocks are not supported.
     
-    {{selective expression}} is allowed in 1.5.8+ only for a subset of functions in `LiveSlides` to include content dynamically.
-    Get a list of all available functions by  `LiveSlides.markdown_callables`.
+    This function was added  in 1.4.6
     
-    New in 1.4.6
+    **New in 1.7.2**    
+    Find special syntax to be used in markdown by `Slides.xmd_syntax`.
+    
+    **New in 1.7.5**
+    Use `Slides.extender` or `ipyslides.extended_md.extender` to add [markdown extensions](https://python-markdown.github.io/extensions/).
     """
     return _ExtendedMarkdown().parse(extended_markdown, display_inline = display_inline, rich_outputs = rich_outputs)  
     
