@@ -1,11 +1,14 @@
 """
 Display source code from files/context managers.
 """
-import ast, re
+import ast, re, os
 import sys, linecache
 import textwrap
 import inspect
-from contextlib import contextmanager
+import pygments
+
+from contextlib import contextmanager, suppress
+from IPython.display import display
 
 from .formatter import highlight, _HTML
     
@@ -25,6 +28,16 @@ class _Source(_HTML):
     def raw(self, value):
         "Set raw source code."
         self._raw = value
+    
+    def display(self,collapsed = False):
+        "Display source object in IPython notebook."
+        if collapsed:
+            return _HTML(f"""<details style='max-height:100%;overflow:auto;'>
+                <summary>Show Code</summary>
+                {self.value}
+                </details>""").display()
+        else:
+            return display(self) # Without collapsed
 
     def show_lines(self, lines):
         "Return source object with selected lines from list/tuple/range of lines."
@@ -98,10 +111,24 @@ class Source:
         return cls.current
     
     @classmethod
-    def from_file(cls, filename,language='python',name=None,**kwargs):
-        "Returns source object with `show_lines` and `focus_lines` methods. `name` is alternate used name for language.`kwargs` are passed to `ipyslides.formatter.highlight`"
-        _title = filename if name is None else name
-        cls.current = _file2code(filename,language=language,name=_title,**kwargs)
+    def from_file(cls, filename,language = None,name = None,**kwargs):
+        """Returns source object with `show_lines` and `focus_lines` methods. `name` is alternate used name for language.  
+        `kwargs` are passed to `ipyslides.formatter.highlight`.     
+        
+        (1.6.8+) tries to auto detect lanaguage from filename extension, if `language` is not given.
+        """
+        _title = name or filename
+        _lang = language or os.path.splitext(filename)[-1].replace('.','')
+        
+        if language is None:
+            lexer = None
+            with suppress(BaseException):
+                lexer = pygments.lexers.get_lexer_by_name(_lang)
+                
+            if lexer is None:
+                raise Exception(f'Failed to detect language from file {filename!r}. Use language argument!')
+            
+        cls.current = _file2code(filename,language = _lang,name = _title,**kwargs)
         return cls.current
     
     @classmethod       
@@ -116,7 +143,7 @@ class Source:
     @classmethod
     @contextmanager 
     def context(cls, **kwargs): 
-        """Execute and displays source code in the context manager. kwargs are passed to `ipyslides.formatter.highlight` function.
+        """Execute and displays source code in the context manager. `kwargs` are passed to `ipyslides.formatter.highlight` function.
         Useful when source is written inside context manager itself.
         
         **Usage**:
