@@ -1,11 +1,12 @@
-__all__ = ['capture_std', 'details', 'set_dir', 'textbox', 'vspace',
+__all__ = ['capture_std', 'details', 'set_dir', 'textbox', 'vspace', 'center',
             'image','svg','iframe', 'format_html','format_css','alert','colored','keep_format',
-            'raw','enable_zoom','html','sig','doc']
+            'raw','enable_zoom','html','sig','doc','code','today','sub','sup']
 __all__.extend(['rows','cols','block'])
-__all__.extend([f'block_{c}' for c in 'rgbycmkowp'])
+__all__.extend([f'block_{c}' for c in 'rgbycma'])
 
 
 import os
+import datetime
 import inspect
 from io import BytesIO # For PIL image
 from contextlib import contextmanager, suppress
@@ -36,6 +37,8 @@ class CapturedStd:
     
 _captured_std = CapturedStd()
 del CapturedStd # No need outside of this module
+
+backtick = '&#96;'
     
 @contextmanager
 def capture_std(): 
@@ -105,19 +108,19 @@ def image(data=None,width='80%',caption=None, zoomable=True,**kwargs):
     _data = __check_pil_image(data) #Check if data is a PIL Image or return data
     img = fix_ipy_image(Image(data = _data,**kwargs),width=width) # gievs _HTML object
     cap = f'<figcaption>{caption}</figcaption>' if caption else ''
-    img = html('figure', img.value + cap)  # Add caption,  _HTML + _HTML
+    _IMG = html('figure', img.value + cap)  # Add caption,  _HTML + _HTML
     if zoomable:
-        return _HTML(f'<div class="zoom-container">{img}</div>')
-    return _HTML(img)
+        return _HTML(f'<div class="zoom-container">{_IMG}</div>')
+    return _IMG # _HTML
 
 def svg(data=None,caption=None,zoomable=True,**kwargs):
     "Display svg file or svg string/bytes with additional customizations. `kwrags` are passed to IPython.display.SVG. You can provide url/string/bytes/filepath for svg."
     svg = SVG(data=data, **kwargs)._repr_svg_()
     cap = f'<figcaption>{caption}</figcaption>' if caption else ''
-    svg = html('figure', svg + cap)
+    _SVG = html('figure', svg + cap)
     if zoomable:
-        return _HTML(f'<div class="zoom-container">{svg}</div>')
-    return _HTML(svg)
+        return _HTML(f'<div class="zoom-container">{_SVG}</div>')
+    return _SVG # _HTML
 
 def iframe(src, width='100%',height='auto',**kwargs):
     "Display `src` in an `iframe`. `kwrags` are passed to IPython.display.IFrame"
@@ -130,13 +133,20 @@ def enable_zoom(obj):
         return ipw.Box([obj]).add_class('zoom-container')
     except:
         return _HTML(f'<div class="zoom-container">{_fix_repr(obj)}</div>')
+
+def center(obj):
+    "Align a given object at center horizontally, whether a widget or html/IPYthon object"
+    try:
+        return ipw.Box([obj]).add_class('Center')
+    except:
+        return _HTML(f'<div class="Center">{_fix_repr(obj)}</div>')
     
 def html(tag, children = None,className = None,**node_attrs):
-    """Returns html node with given children and node attributes like style, id etc.
-    `tag` can be any valid html tag name.
+    """Returns html node with given children and node attributes like style, id etc. If an ttribute needs '-' in its name, replace it with '_'.     
+    `tag` can be any valid html tag name. A `tag` that ends with `/` will be self closing e.g. `hr/` will be `<hr/>`.     
     `children` expects:
     
-    - If None, returns self closing html node such as <img alt='Image'></img>.
+    - If None, returns node such as 'image' -> <img alt='Image'></img> and 'image/' -> <img alt='Image' />
     - str: A string to be added as node's text content.
     - list/tuple of [objects]: A list of objects that will be parsed and added as child nodes. Widgets are not supported.
     
@@ -145,18 +155,25 @@ def html(tag, children = None,className = None,**node_attrs):
     html('img',src='ir_uv.jpg') #Returns IPython.display.HTML("<img src='ir_uv.jpg'></img>") and displas image if last line in notebook's cell.
     ```
     """
+    if children and tag.endswith('/'):
+        raise ValueError(f'Parametr `children` should be None for self closing tag {tag!r}')
+    
+    node_attrs = {'style':"background:inherit;color:inherit;",**{k.replace('_','-'):v for k,v in node_attrs.items()}} # replace _ with - in keys, and add default style
+    attrs = ' '.join(f'{k}="{v}"' for k,v in node_attrs.items()) # Join with space is must
+    if className:
+        attrs = f'class="{className}" {attrs}'
+    
+    if tag.endswith('/'): # Self closing tag
+        return _HTML(f'<{tag[:-1]} {attrs} />' if attrs else f'<{tag[:-1]}/>')
+    
     if children is None:
         content = ''
     elif isinstance(children,str):
         content = children
     elif isinstance(children,(list,tuple)):
-        content = format_html(children) # Convert to html nodes in sequence of rows
+        content = '\n'.join(_fix_repr(child) for child in children) # Convert to html nodes in sequence of rows
     else:
         raise ValueError(f'Children should be a list/tuple of objects or str, not {type(children)}')
-    
-    attrs = ' '.join(f'{k}="{v}"' for k,v in node_attrs.items()) # Join with space is must
-    if className:
-        attrs = f'class="{className}" {attrs}'
         
     tag_in =  f'<{tag} {attrs}>' if attrs else f'<{tag}>' # space is must after tag, strip attrs spaces
     return _HTML(f'{tag_in}{content}</{tag}>')
@@ -179,7 +196,7 @@ def alert(text):
     
 def colored(text,fg='blue',bg=None):
     "Colored text, `fg` and `bg` should be valid CSS colors"
-    return _HTML(f"<span style='background:{bg};color:{fg};'>{text}</span>")
+    return _HTML(f"<span style='background:{bg};color:{fg};padding: 0.1em;border-radius:0.1em;'>{text}</span>")
 
 def keep_format(plaintext_or_html):
     "Bypasses from being parsed by markdown parser. Useful for some graphs, e.g. keep_raw(obj.to_html()) preserves its actual form."
@@ -200,47 +217,20 @@ def cols(*objs,width_percents=None, className=None):
     "Returns HTML containing multiple columns of given width_percents."
     return format_html(*objs,width_percents=width_percents,className = className)
 
-def block(title,*objs,bg = 'olive'):
-    "Format a block like in LATEX beamer. *objs expect to be writable with `write` command."
-    _title = f"""<center style='background:var(--secondary-bg);margin:0px -4px;'>
-                <b>{title}</b></center>"""
-    _out = _fmt_write(objs) # single column
-    return _HTML(f"""<div style='padding:4px' class='block'>
-        <div style='border-top:4px solid {bg};box-shadow: 0px 0px 4px {bg};border-radius:4px;padding:0 4px;'>
-        {_title}
-        {_out}
-        </div></div>""")
+def block(*objs,className = 'Block'):
+    """Format a block like in LATEX beamer. *objs expect to be writable with `write` command.   
+    Shortcut functions with pre-specified background colors are available: `block_<r,g,b,y,c,m,a>`.
+    In 1.7.5+, you can create blocks just by CSS classes in markdown as {.Block}, {.Block-red}, {.Block-green}, etc.
+    """
+    return _HTML(f"<div class='{className}'>{_fmt_write(objs)}</div>")
     
-def block_r(title,*objs):
-    "See documentation of `block`."
-    return block(title,*objs,bg='crimson')
-def block_b(title,*objs):
-    "See documentation of `block`."
-    return block(title,*objs,bg='navy')
-def block_g(title,*objs):
-    "See documentation of `block`."
-    return block(title,*objs,bg='#006400')
-def block_y(title,*objs):
-    "See documentation of `block`."
-    return block(title,*objs,bg='#E4D00A')
-def block_o(title,*objs):
-    "See documentation of `block`."
-    return block(title,*objs,bg='orange')
-def block_p(title,*objs):
-    "See documentation of `block`."
-    return block(title,*objs,bg='purple')
-def block_c(title,*objs):
-    "See documentation of `block`."
-    return block(title,*objs,bg='#48d1cc')
-def block_m(title,*objs):
-    "See documentation of `block`."
-    return block(title,*objs,bg='magenta')
-def block_w(title,*objs):
-    "See documentation of `block`."
-    return block(title,*objs,bg='whitesmoke')
-def block_k(title,*objs):
-    "See documentation of `block`."
-    return block(title,*objs,bg='#343434')
+def block_r(*objs): return block(*objs,className = 'Block-red')
+def block_b(*objs): return block(*objs,className = 'Block-blue')
+def block_g(*objs): return block(*objs,className = 'Block-green')
+def block_y(*objs): return block(*objs,className = 'Block-yellow')
+def block_c(*objs): return block(*objs,className = 'Block-cyan')
+def block_m(*objs): return block(*objs,className = 'Block-magenta')
+def block_a(*objs): return block(*objs,className = 'Block-gray')
 
 def sig(callable,prepend_str = None):
     "Returns signature of a callable. You can prepend a class/module name."
@@ -253,17 +243,18 @@ def sig(callable,prepend_str = None):
         raise TypeError(f'Object {callable} is not a callable')
 
 
-def doc(obj,prepend_str = None, members=None):
+def doc(obj,prepend_str = None, members = None, itself = True):
     "Returns documentation of an `obj`. You can prepend a class/module name. members is True/List of attributes to show doc of."
     if obj is None:
         return _HTML('') # Must be _HTML to work on memebers
     
     _doc, _sig, _full_doc = '', '', ''
-    with suppress(BaseException): # if not __doc__, go forwards
-        _doc += _fix_repr((inspect.getdoc(obj) or '').replace('{','\u2774').replace('}','\u2775'))
-    
-    with suppress(BaseException): # This allows to get docs of module without signature
-        _sig = sig(obj,prepend_str)
+    if itself == True:
+        with suppress(BaseException): # if not __doc__, go forwards
+            _doc += _fix_repr((inspect.getdoc(obj) or '').replace('{','\u2774').replace('}','\u2775'))
+
+        with suppress(BaseException): # This allows to get docs of module without signature
+            _sig = sig(obj,prepend_str)
     
     # If above fails, try to get name of module/object
     _name = obj.__name__ if hasattr(obj,'__name__') else type(obj).__name__
@@ -276,7 +267,8 @@ def doc(obj,prepend_str = None, members=None):
         return _HTML('') # Must be _HTML to work on memebers
     
     _sig = _sig or colored(_pstr,"var(--accent-color)") # Picks previous signature if exists
-    _full_doc = f"<div class='Docs'>{_sig}<br>{_doc}\n</div>"
+    _full_doc = f"<div class='Docs'>{_sig}<br>{_doc}\n</div>" if itself == True else ''
+    _pstr = (prepend_str or _pstr) if itself == False else _pstr # Prefer given string if itself is not to doc
     
     _mems = []
     if members == True:
@@ -305,7 +297,24 @@ def doc(obj,prepend_str = None, members=None):
     # Collect docs of members
     for attr in _mems:
         with suppress(BaseException):
-            _class_members = inspect.ismodule(obj) and inspect.isclass(attr)
-            _full_doc += doc(attr, prepend_str=f'{_pstr}',members = _class_members).value
+            _class_members = inspect.ismodule(obj) and (inspect.isclass(attr) and (attr.__module__ == obj.__name__)) # Restrict imported classes in docs
+            _full_doc += doc(attr, prepend_str = _pstr, members = _class_members, itself = True).value
     
-    return _HTML(_full_doc)
\ No newline at end of file
+    return _HTML(_full_doc)
+
+def code(callable):
+    "Returns full code of a callable. Added in 1.7.9, you can just pass callable into `write` command or use `ipyslides.Slides().source.from_callable`."
+    try:
+        return _HTML(_fix_repr(callable))
+    except:
+        raise TypeError(f'Object {callable} is not a callable')
+
+def today(fmt = '%b %d, %Y',color = 'inherit'): # Should be inherit color for markdown flow
+    "Returns today's date in given format."
+    return colored(datetime.datetime.now().strftime(fmt),fg=color, bg = None)
+
+def sub(text):
+    return html('sub',text,style="font-size:70%;color:inherit;")
+
+def sup(text):
+    return html('sup',text,style="font-size:70%;color:inherit;")
\ No newline at end of file
